@@ -1,21 +1,7 @@
 /*
-    Copyright 2013 Jan Grulich <jgrulich@redhat.com>
+    SPDX-FileCopyrightText: 2013 Jan Grulich <jgrulich@redhat.com>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) version 3, or any
-    later version accepted by the membership of KDE e.V. (or its
-    successor approved by the membership of KDE e.V.), which shall
-    act as a proxy defined in Section 6 of version 3 of the license.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 #include "connectionicon.h"
@@ -35,7 +21,7 @@
 #include <ModemManagerQt/manager.h>
 #endif
 
-ConnectionIcon::ConnectionIcon(QObject* parent)
+ConnectionIcon::ConnectionIcon(QObject *parent)
     : QObject(parent)
     , m_signal(0)
     , m_wirelessNetwork(nullptr)
@@ -83,7 +69,7 @@ ConnectionIcon::ConnectionIcon(QObject* parent)
 
     QDBusPendingReply<uint> pendingReply = NetworkManager::checkConnectivity();
     QDBusPendingCallWatcher *callWatcher = new QDBusPendingCallWatcher(pendingReply);
-    connect(callWatcher, &QDBusPendingCallWatcher::finished, this, [this] (QDBusPendingCallWatcher *watcher) {
+    connect(callWatcher, &QDBusPendingCallWatcher::finished, this, [this](QDBusPendingCallWatcher *watcher) {
         QDBusPendingReply<uint> reply = *watcher;
         if (reply.isValid()) {
             connectivityChanged((NetworkManager::Connectivity)reply.value());
@@ -119,7 +105,7 @@ QString ConnectionIcon::connectionTooltipIcon() const
     return m_connectionTooltipIcon;
 }
 
-void ConnectionIcon::activatingConnectionChanged(const QString& connection)
+void ConnectionIcon::activatingConnectionChanged(const QString &connection)
 {
     Q_UNUSED(connection);
     setIcons();
@@ -174,7 +160,7 @@ void ConnectionIcon::connectivityChanged(NetworkManager::Connectivity conn)
     setLimited(conn == NetworkManager::Portal || conn == NetworkManager::Limited);
 }
 
-void ConnectionIcon::deviceAdded(const QString& device)
+void ConnectionIcon::deviceAdded(const QString &device)
 {
     NetworkManager::Device::Ptr dev = NetworkManager::findNetworkInterface(device);
 
@@ -188,7 +174,7 @@ void ConnectionIcon::deviceAdded(const QString& device)
     }
 }
 
-void ConnectionIcon::deviceRemoved(const QString& device)
+void ConnectionIcon::deviceRemoved(const QString &device)
 {
     Q_UNUSED(device);
 
@@ -207,8 +193,7 @@ void ConnectionIcon::modemSignalChanged(const ModemManager::SignalQualityPair &s
 {
     int diff = m_signal - signalQuality.signal;
 
-    if (diff >= 10 ||
-        diff <= -10) {
+    if (diff >= 10 || diff <= -10) {
         m_signal = signalQuality.signal;
 
         setIconForModem();
@@ -223,7 +208,7 @@ void ConnectionIcon::networkingEnabledChanged(bool enabled)
     }
 }
 
-void ConnectionIcon::primaryConnectionChanged(const QString& connection)
+void ConnectionIcon::primaryConnectionChanged(const QString &connection)
 {
     if (!connection.isEmpty()) {
         setIcons();
@@ -255,10 +240,9 @@ void ConnectionIcon::wwanEnabledChanged(bool enabled)
 {
     Q_UNUSED(enabled);
     setIcons();
-
 }
 
-void ConnectionIcon::wirelessNetworkAppeared(const QString& network)
+void ConnectionIcon::wirelessNetworkAppeared(const QString &network)
 {
     Q_UNUSED(network);
     setIcons();
@@ -284,10 +268,10 @@ void ConnectionIcon::setStates()
         } else {
             if (vpnConnection->state() == NetworkManager::VpnConnection::Activated) {
                 vpn = true;
-            } else if (vpnConnection->state() == NetworkManager::VpnConnection::Prepare ||
-                       vpnConnection->state() == NetworkManager::VpnConnection::NeedAuth ||
-                       vpnConnection->state() == NetworkManager::VpnConnection::Connecting ||
-                       vpnConnection->state() == NetworkManager::VpnConnection::GettingIpConfig) {
+            } else if (vpnConnection->state() == NetworkManager::VpnConnection::Prepare //
+                       || vpnConnection->state() == NetworkManager::VpnConnection::NeedAuth //
+                       || vpnConnection->state() == NetworkManager::VpnConnection::Connecting //
+                       || vpnConnection->state() == NetworkManager::VpnConnection::GettingIpConfig) {
                 connecting = true;
             }
         }
@@ -315,8 +299,7 @@ void ConnectionIcon::setIcons()
 
     // Set icon based on the current primary connection if the activating connection is virtual
     // since we're not setting icons for virtual connections
-    if (!connection
-        || (connection && UiUtils::isConnectionTypeVirtual(connection->type()))
+    if (!connection || (connection && UiUtils::isConnectionTypeVirtual(connection->type()))
         || connection->type() == NetworkManager::ConnectionSettings::WireGuard) {
         connection = NetworkManager::primaryConnection();
     }
@@ -325,7 +308,7 @@ void ConnectionIcon::setIcons()
                  of generic type (some type of VPNs) we need to go through all other active connections and pick the one with
                  highest probability of being the main one (order is: vpn, wired, wireless, gsm, cdma, bluetooth) */
     if ((!connection && !NetworkManager::activeConnections().isEmpty()) || (connection && connection->type() == NetworkManager::ConnectionSettings::Generic)
-                                                                        || (connection && connection->type() == NetworkManager::ConnectionSettings::Tun)) {
+        || (connection && connection->type() == NetworkManager::ConnectionSettings::Tun)) {
         for (const NetworkManager::ActiveConnection::Ptr &activeConnection : NetworkManager::activeConnections()) {
             const NetworkManager::ConnectionSettings::ConnectionType type = activeConnection->type();
             if (type == NetworkManager::ConnectionSettings::Bluetooth) {
@@ -345,13 +328,15 @@ void ConnectionIcon::setIcons()
             } else if (type == NetworkManager::ConnectionSettings::WireGuard) {
                 connection = activeConnection;
             } else if (type == NetworkManager::ConnectionSettings::Wired) {
-                if (connection && (connection->type() != NetworkManager::ConnectionSettings::Vpn
-                                  || connection->type() != NetworkManager::ConnectionSettings::WireGuard)) {
+                if (connection
+                    && (connection->type() != NetworkManager::ConnectionSettings::Vpn //
+                        || connection->type() != NetworkManager::ConnectionSettings::WireGuard)) {
                     connection = activeConnection;
                 }
             } else if (type == NetworkManager::ConnectionSettings::Wireless) {
-                if (connection && (connection->type() != NetworkManager::ConnectionSettings::Vpn &&
-                                  (connection->type() != NetworkManager::ConnectionSettings::Wired))) {
+                if (connection
+                    && (connection->type() != NetworkManager::ConnectionSettings::Vpn //
+                        && (connection->type() != NetworkManager::ConnectionSettings::Wired))) {
                     connection = activeConnection;
                 }
             }
@@ -398,7 +383,7 @@ void ConnectionIcon::setIcons()
                         setConnectionTooltipIcon("preferences-system-bluetooth");
                     }
                 }
-            } else if (type == 29) {      // TODO change to WireGuard enum value once it is added
+            } else if (type == 29) { // TODO change to WireGuard enum value once it is added
                 // WireGuard is a VPN but is not implemented
                 // in NetworkManager as a VPN, so we don't want to
                 // do anything just because it has a device
@@ -420,8 +405,8 @@ void ConnectionIcon::setDisconnectedIcon()
         return;
     }
 
-    if (NetworkManager::status() == NetworkManager::Unknown ||
-        NetworkManager::status() == NetworkManager::Asleep) {
+    if (NetworkManager::status() == NetworkManager::Unknown //
+        || NetworkManager::status() == NetworkManager::Asleep) {
         setConnectionIcon("network-unavailable");
         return;
     }
@@ -439,16 +424,16 @@ void ConnectionIcon::setDisconnectedIcon()
             if (wiredDev->carrier()) {
                 wired = true;
             }
-        } else if (device->type() == NetworkManager::Device::Wifi &&
-                   NetworkManager::isWirelessEnabled() &&
-                   NetworkManager::isWirelessHardwareEnabled()) {
+        } else if (device->type() == NetworkManager::Device::Wifi //
+                   && NetworkManager::isWirelessEnabled() //
+                   && NetworkManager::isWirelessHardwareEnabled()) {
             NetworkManager::WirelessDevice::Ptr wifiDevice = device.objectCast<NetworkManager::WirelessDevice>();
             if (!wifiDevice->accessPoints().isEmpty() || !wifiDevice->availableConnections().isEmpty()) {
                 wireless = true;
             }
-        } else if (device->type() == NetworkManager::Device::Modem &&
-                   NetworkManager::isWwanEnabled() &&
-                   NetworkManager::isWwanHardwareEnabled()) {
+        } else if (device->type() == NetworkManager::Device::Modem //
+                   && NetworkManager::isWwanEnabled() //
+                   && NetworkManager::isWwanHardwareEnabled()) {
             modem = true;
         }
     }
@@ -465,14 +450,14 @@ void ConnectionIcon::setDisconnectedIcon()
         setConnectionIcon("network-mobile-available");
         setConnectionTooltipIcon("phone");
         return;
-    }  else {
+    } else {
         setConnectionIcon("network-unavailable");
         setConnectionTooltipIcon("network-wired");
     }
 }
 
 #if WITH_MODEMMANAGER_SUPPORT
-void ConnectionIcon::setModemIcon(const NetworkManager::Device::Ptr & device)
+void ConnectionIcon::setModemIcon(const NetworkManager::Device::Ptr &device)
 {
     NetworkManager::ModemDevice::Ptr modemDevice = device.objectCast<NetworkManager::ModemDevice>();
 
@@ -526,7 +511,7 @@ void ConnectionIcon::setIconForModem()
 
     QString result;
 
-    switch(m_modemNetwork->accessTechnologies()) {
+    switch (m_modemNetwork->accessTechnologies()) {
     case MM_MODEM_ACCESS_TECHNOLOGY_GSM:
     case MM_MODEM_ACCESS_TECHNOLOGY_GSM_COMPACT:
         result = "network-mobile-%1";
@@ -563,7 +548,7 @@ void ConnectionIcon::setIconForModem()
 }
 #endif
 
-void ConnectionIcon::setWirelessIcon(const NetworkManager::Device::Ptr &device, const QString& ssid)
+void ConnectionIcon::setWirelessIcon(const NetworkManager::Device::Ptr &device, const QString &ssid)
 {
     NetworkManager::WirelessDevice::Ptr wirelessDevice = device.objectCast<NetworkManager::WirelessDevice>();
     if (device) {
@@ -573,7 +558,11 @@ void ConnectionIcon::setWirelessIcon(const NetworkManager::Device::Ptr &device,
     }
 
     if (m_wirelessNetwork) {
-        connect(m_wirelessNetwork.data(), &NetworkManager::WirelessNetwork::signalStrengthChanged, this, &ConnectionIcon::setWirelessIconForSignalStrength, Qt::UniqueConnection);
+        connect(m_wirelessNetwork.data(),
+                &NetworkManager::WirelessNetwork::signalStrengthChanged,
+                this,
+                &ConnectionIcon::setWirelessIconForSignalStrength,
+                Qt::UniqueConnection);
 
         setWirelessIconForSignalStrength(m_wirelessNetwork->signalStrength());
     } else {
@@ -616,7 +605,7 @@ void ConnectionIcon::setConnecting(bool connecting)
     }
 }
 
-void ConnectionIcon::setConnectionIcon(const QString & icon)
+void ConnectionIcon::setConnectionIcon(const QString &icon)
 {
     if (icon != m_connectionIcon) {
         m_connectionIcon = icon;
@@ -624,7 +613,7 @@ void ConnectionIcon::setConnectionIcon(const QString & icon)
     }
 }
 
-void ConnectionIcon::setConnectionTooltipIcon(const QString & icon)
+void ConnectionIcon::setConnectionTooltipIcon(const QString &icon)
 {
     if (icon != m_connectionTooltipIcon) {
         m_connectionTooltipIcon = icon;
