@@ -1,31 +1,17 @@
 /*
-    Copyright 2011 Ilia Kats <ilia-kats@gmx.net>
-    Copyright 2013 Jan Grulich <jgrulich@redhat.com>
+    SPDX-FileCopyrightText: 2011 Ilia Kats <ilia-kats@gmx.net>
+    SPDX-FileCopyrightText: 2013 Jan Grulich <jgrulich@redhat.com>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) version 3, or any
-    later version accepted by the membership of KDE e.V. (or its
-    successor approved by the membership of KDE e.V.), which shall
-    act as a proxy defined in Section 6 of version 3 of the license.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 #include "advancedpermissionswidget.h"
 #include "ui_advancedpermissionswidget.h"
 
-#include <KUser>
-#include <KLocalizedString>
-#include <QList>
 #include <KAcceleratorManager>
+#include <KLocalizedString>
+#include <KUser>
+#include <QList>
 
 #define UserTagRole Qt::UserRole + 1
 
@@ -35,9 +21,9 @@ public:
     Ui_AdvancedPermissions ui;
 };
 
-AdvancedPermissionsWidget::AdvancedPermissionsWidget(QWidget *parent):
-    QDialog(parent),
-    d_ptr(new AdvancedPermissionsWidgetPrivate)
+AdvancedPermissionsWidget::AdvancedPermissionsWidget(QWidget *parent)
+    : QDialog(parent)
+    , d_ptr(new AdvancedPermissionsWidgetPrivate)
 {
     Q_D(AdvancedPermissionsWidget);
     d->ui.setupUi(this);
@@ -49,9 +35,9 @@ AdvancedPermissionsWidget::AdvancedPermissionsWidget(QWidget *parent):
     setupCommon();
 }
 
-AdvancedPermissionsWidget::AdvancedPermissionsWidget(const QHash<QString,QString> &users, QWidget *parent):
-    QDialog(parent),
-    d_ptr(new AdvancedPermissionsWidgetPrivate)
+AdvancedPermissionsWidget::AdvancedPermissionsWidget(const QHash<QString, QString> &users, QWidget *parent)
+    : QDialog(parent)
+    , d_ptr(new AdvancedPermissionsWidgetPrivate)
 {
     Q_D(AdvancedPermissionsWidget);
     d->ui.setupUi(this);
@@ -91,7 +77,7 @@ void AdvancedPermissionsWidget::setupCommon()
     KAcceleratorManager::manage(this);
 }
 
-QTreeWidgetItem * AdvancedPermissionsWidget::constructItem(const KUser &user, const QString &itemData)
+QTreeWidgetItem *AdvancedPermissionsWidget::constructItem(const KUser &user, const QString &itemData)
 {
     QStringList data;
     QString name = user.property(KUser::FullName).toString();
