@@ -1,32 +1,18 @@
 /*
-    Copyright 2015 Jan Grulich <jgrulich@redhat.com>
+    SPDX-FileCopyrightText: 2015 Jan Grulich <jgrulich@redhat.com>
 
-    This program is free software; you can redistribute it and/or
-    modify it under the terms of the GNU General Public License as
-    published by the Free Software Foundation; either version 2 of
-    the License or (at your option) version 3 or any later version
-    accepted by the membership of KDE e.V. (or its successor approved
-    by the membership of KDE e.V.), which shall act as a proxy
-    defined in Section 14 of version 3 of the license.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
 #include "ssh.h"
-#include "sshwidget.h"
 #include "sshauth.h"
+#include "sshwidget.h"
 
 #include <KPluginFactory>
 
 K_PLUGIN_CLASS_WITH_JSON(SshUiPlugin, "plasmanetworkmanagement_sshui.json")
 
-SshUiPlugin::SshUiPlugin(QObject * parent, const QVariantList &)
+SshUiPlugin::SshUiPlugin(QObject *parent, const QVariantList &)
     : VpnUiPlugin(parent)
 {
 }
@@ -35,14 +21,14 @@ SshUiPlugin::~SshUiPlugin()
 {
 }
 
-SettingWidget * SshUiPlugin::widget(const NetworkManager::VpnSetting::Ptr &setting, QWidget * parent)
+SettingWidget *SshUiPlugin::widget(const NetworkManager::VpnSetting::Ptr &setting, QWidget *parent)
 {
     return new SshSettingWidget(setting, parent);
 }
 
-SettingWidget * SshUiPlugin::askUser(const NetworkManager::VpnSetting::Ptr &setting, QWidget * parent)
+SettingWidget *SshUiPlugin::askUser(const NetworkManager::VpnSetting::Ptr &setting, const QStringList &hints, QWidget *parent)
 {
-    return new SshAuthWidget(setting, parent);
+    return new SshAuthWidget(setting, hints, parent);
 }
 
 QString SshUiPlugin::suggestedFileName(const NetworkManager::ConnectionSettings::Ptr &connection) const
